#ifndef _ECORE_AUDIO_IN_TONE_EO_H_
#define _ECORE_AUDIO_IN_TONE_EO_H_

#ifndef _ECORE_AUDIO_IN_TONE_EO_CLASS_TYPE
#define _ECORE_AUDIO_IN_TONE_EO_CLASS_TYPE

typedef Eo Ecore_Audio_In_Tone;

#endif

#ifndef _ECORE_AUDIO_IN_TONE_EO_TYPES
#define _ECORE_AUDIO_IN_TONE_EO_TYPES


#endif
/** Ecore Audio tone input.
 *
 * @ingroup Ecore_Audio_In_Tone
 */
#define ECORE_AUDIO_IN_TONE_CLASS ecore_audio_in_tone_class_get()

EWAPI const Efl_Class *ecore_audio_in_tone_class_get(void);

#endif
